//
//  MapExampleViewController.m
//  MapExample
//
//  Created by DARTS Lab on 3/27/11.
//  Copyright 2011 __MyCompanyName__. All rights reserved.
//

#import "MapExampleViewController.h"

@implementation MapExampleViewController

@synthesize map;
@synthesize latitude;
@synthesize longitude;
@synthesize accuracy;
@synthesize locManager;
@synthesize myPin;

- (void)locationManager:(CLLocationManager *)manager 
			didUpdateToLocation:(CLLocation *)newLocation
		   fromLocation:(CLLocation *)oldLocation {
	self.latitude.text = [NSString stringWithFormat:@"%.4f", newLocation.coordinate.latitude];
	self.longitude.text = [NSString stringWithFormat:@"%.4f", newLocation.coordinate.longitude];
	self.accuracy.text = [NSString stringWithFormat:@"%.2f m", newLocation.horizontalAccuracy];
	
	if (MKMapRectContainsPoint(self.map.visibleMapRect, MKMapPointForCoordinate(newLocation.coordinate))) {
		return;
	}

	[self.map setCenterCoordinate:newLocation.coordinate animated:YES];
	if (self.myPin) {
		[self.map removeAnnotation:self.myPin];
	}
	self.myPin = [MyPin initWithCoordinate:newLocation.coordinate];
	[self.map addAnnotation:self.myPin];

}

- (MKAnnotationView *)mapView:(MKMapView *)mapView viewForAnnotation:(id <MKAnnotation>)annotation {
	static NSString *ident = @"mypin";
	MKAnnotationView *aView = [mapView dequeueReusableAnnotationViewWithIdentifier:ident];
	if (!aView) {
		aView = [[[MKPinAnnotationView alloc] initWithAnnotation:annotation reuseIdentifier:ident] autorelease];
		aView.canShowCallout = YES;
	}
	aView.annotation = annotation;
	return aView;
}

- (void)mapView:(MKMapView *)mapView didSelectAnnotationView:(MKAnnotationView *)view {
	view.rightCalloutAccessoryView = [UIButton buttonWithType:UIButtonTypeDetailDisclosure];
	UIImageView *imgView = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"smdome.png"]];
	view.leftCalloutAccessoryView = imgView;
	[imgView release];
}
	
- (void)mapView:(MKMapView *)mapView annotationView:(MKAnnotationView *)view calloutAccessoryControlTapped:(UIControl *)control {
	// do something here when annotation is clicked

}

/*
// The designated initializer. Override to perform setup that is required before the view is loaded.
- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}
*/

/*
// Implement loadView to create a view hierarchy programmatically, without using a nib.
- (void)loadView {
}
*/



// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad {
    [super viewDidLoad];
	if ([CLLocationManager locationServicesEnabled]) {
		self.locManager = [[[CLLocationManager alloc] init] autorelease];
		self.locManager.desiredAccuracy = kCLLocationAccuracyHundredMeters;
		self.locManager.distanceFilter = 0;
		self.locManager.delegate = self;
		[self.locManager startUpdatingLocation];
	}
	else {
		// handle location disabled
		NSLog(@"location service not enabled");
	}
	self.map.mapType = MKMapTypeStandard;
	self.map.delegate = self;
	[self.map setRegion:MKCoordinateRegionMake(self.map.centerCoordinate, MKCoordinateSpanMake(.015, .015)) animated:YES];
		
}



/*
// Override to allow orientations other than the default portrait orientation.
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}
*/

- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;
	[self.locManager stopUpdatingLocation];
}


- (void)dealloc {
	self.locManager.delegate = nil;
	self.map.delegate = nil;
	[locManager release];
	[map release];
	[latitude release];
	[longitude release];
	[accuracy release];
	[myPin release];
    [super dealloc];
}

@end
